@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: pty.c,v 1.43 2003/05/05 02:51:51 nalin Exp $"
+#ident "$Id: pty.c,v 1.44 2003/05/19 22:48:57 nalin Exp $"
 #include "../config.h"
 #include <sys/types.h>
 #include <sys/ioctl.h>
@@ -710,6 +710,9 @@ _vte_pty_getpt(void)
 #else
 	/* Try to allocate a pty by accessing the pty master multiplex. */
 	fd = open("/dev/ptmx", O_RDWR | O_NOCTTY);
+	if ((fd == -1) && (errno == ENOENT)) {
+		fd = open("/dev/ptc", O_RDWR | O_NOCTTY); /* AIX */
+	}
 #endif
 	/* Set it to blocking. */
 	flags = fcntl(fd, F_GETFL);
