@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vtefc.c,v 1.8 2003/05/05 23:23:46 nalin Exp $"
+#ident "$Id: vtefc.c,v 1.11 2003/05/21 21:42:17 nalin Exp $"
 
 #include "../config.h"
 
@@ -117,6 +117,8 @@ _vte_fc_transcribe_from_pango_font_description(FcPattern *pattern,
 		FcPatternAddInteger(pattern, FC_SLANT,
 				    _vte_fc_slant_from_pango_style(style));
 	}
+
+	g_object_unref(G_OBJECT(context));
 }
 
 static void
@@ -200,6 +202,7 @@ _vte_fc_defaults_from_gtk(FcPattern *pattern)
 			FcPatternDel(pattern, FC_RGBA);
 			FcPatternAddInteger(pattern, FC_RGBA, i);
 		}
+		g_free(rgba);
 	}
 
 	/* Pick up the configured hinting setting. */
@@ -237,6 +240,7 @@ _vte_fc_defaults_from_gtk(FcPattern *pattern)
 			FcPatternDel(pattern, FC_HINT_STYLE);
 			FcPatternAddInteger(pattern, FC_HINT_STYLE, i);
 		}
+		g_free(hintstyle);
 	}
 #endif
 }
@@ -330,7 +334,7 @@ _vte_fc_patterns_from_pango_font_desc(const PangoFontDescription *font_desc,
 				      gpointer defaults_data)
 
 {
-	FcPattern *pattern, *match, *tmp;
+	FcPattern *pattern, *match, *tmp, *save;
 	FcFontSet *fontset;
 	FcResult result;
 	gboolean ret = FALSE;
@@ -370,7 +374,9 @@ _vte_fc_patterns_from_pango_font_desc(const PangoFontDescription *font_desc,
 						  pattern,
 						  fontset->fonts[i]);
 			_vte_fc_defaults_from_gtk(tmp);
-			g_array_append_val(pattern_array, tmp);
+			save = FcPatternDuplicate(tmp);
+			FcPatternDestroy(tmp);
+			g_array_append_val(pattern_array, save);
 		}
 		FcFontSetDestroy(fontset);
 		ret = TRUE;
@@ -382,7 +388,9 @@ _vte_fc_patterns_from_pango_font_desc(const PangoFontDescription *font_desc,
 		if (result == FcResultMatch) {
 			tmp = FcPatternDuplicate(match);
 			_vte_fc_defaults_from_gtk(tmp);
-			g_array_append_val(pattern_array, tmp);
+			save = FcPatternDuplicate(tmp);
+			FcPatternDestroy(tmp);
+			g_array_append_val(pattern_array, save);
 			ret = TRUE;
 		} else {
 			ret = FALSE;
