@@ -16,6 +16,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ident "$Id: vteft2.c,v 1.8 2003/05/19 20:55:11 nalin Exp $"
+
 #include "../config.h"
 
 #include <sys/param.h>
@@ -24,6 +26,7 @@
 #include <glib.h>
 #include <fontconfig/fontconfig.h>
 #include "debug.h"
+#include "vtebg.h"
 #include "vtedraw.h"
 #include "vtefc.h"
 #include "vteglyph.h"
@@ -130,7 +133,7 @@ _vte_ft2_end(struct _vte_draw *draw)
 	    (data->bottom == -1)) {
 		_vte_rgb_draw_on_drawable(widget->window,
 					  widget->style->fg_gc[state],
-					  0, 0, 
+					  0, 0,
 					  width, height,
 					  data->rgb,
 					  0, 0);
@@ -154,19 +157,24 @@ _vte_ft2_set_background_color(struct _vte_draw *draw, GdkColor *color)
 }
 
 static void
-_vte_ft2_set_background_pixbuf(struct _vte_draw *draw, GdkPixbuf *pixbuf)
+_vte_ft2_set_background_image(struct _vte_draw *draw,
+			      enum VteBgSourceType type,
+			      GdkPixbuf *pixbuf,
+			      const char *file,
+			      const GdkColor *color,
+			      double saturation)
 {
 	struct _vte_ft2_data *data;
+	GdkPixbuf *bgpixbuf;
 
 	data = (struct _vte_ft2_data*) draw->impl_data;
 
+	bgpixbuf = vte_bg_get_pixbuf(vte_bg_get(), type, pixbuf, file,
+				     color, saturation);
 	if (GDK_IS_PIXBUF(data->pixbuf)) {
 		g_object_unref(G_OBJECT(data->pixbuf));
 	}
-	data->pixbuf = pixbuf;
-	if (GDK_IS_PIXBUF(data->pixbuf)) {
-		g_object_ref(G_OBJECT(data->pixbuf));
-	}
+	data->pixbuf = bgpixbuf;
 }
 
 static void
@@ -215,7 +223,8 @@ _vte_ft2_set_text_font(struct _vte_draw *draw,
 		data->cache = NULL;
 	}
 	data->cache = _vte_glyph_cache_new();
-	_vte_glyph_cache_set_font_description(NULL, data->cache, fontdesc);
+	_vte_glyph_cache_set_font_description(NULL, data->cache, fontdesc,
+					      NULL, NULL);
 }
 
 static int
@@ -330,7 +339,8 @@ struct _vte_draw_impl _vte_draw_ft2 = {
 	_vte_ft2_start,
 	_vte_ft2_end,
 	_vte_ft2_set_background_color,
-	_vte_ft2_set_background_pixbuf,
+	_vte_ft2_set_background_image,
+	FALSE,
 	_vte_ft2_clear,
 	_vte_ft2_set_text_font,
 	_vte_ft2_get_text_width,
